@@ -1,8 +1,8 @@
-                /*
-    SPDX-FileCopyrightText: 2007-2012 Urs Wolfer <uwolfer@kde.org>
-    SPDX-FileCopyrightText: 2012 AceLan Kao <acelan@acelan.idv.tw>
+/*
+SPDX-FileCopyrightText: 2007-2012 Urs Wolfer <uwolfer@kde.org>
+SPDX-FileCopyrightText: 2012 AceLan Kao <acelan@acelan.idv.tw>
 
-    SPDX-License-Identifier: GPL-2.0-or-later
+SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #ifndef RDPHOSTPREFERENCES_H
@@ -48,6 +48,19 @@ public:
         Depth8,
     };
 
+    enum class TlsSecLevel {
+        Any,
+        Bit80,
+        Bit112,
+        Bit128,
+        Bit192,
+        Bit256,
+    };
+
+    enum class ProxyProtocol { HTTP, SOCKS };
+
+    enum class GatewayTransportType { Auto, HTTP, RPC };
+
     explicit RdpHostPreferences(KConfigGroup configGroup, QObject *parent = nullptr);
     ~RdpHostPreferences() override;
 
@@ -73,8 +86,40 @@ public:
     void setShareMedia(const QString &shareMedia);
     QString shareMedia() const;
 
+    TlsSecLevel tlsSecLevel() const;
+    void setTlsSecLevel(TlsSecLevel tlsSecLevel);
+
+    // Proxy settings
+    ProxyProtocol proxyProtocol() const;
+    void setProxyProtocol(ProxyProtocol proxyProtocol);
+
+    QString proxyUsername() const;
+    void setProxyUsername(const QString &proxyUsername);
+
+    QString proxyPassword() const;
+    void setProxyPassword(const QString &proxyPassword);
+
+    QString proxyHost() const;
+    void setProxyHost(const QString &proxyHost);
+
+    // Gateway settings
+    GatewayTransportType gatewayTransportType() const;
+    void setGatewayTransportType(GatewayTransportType gatewayTransportType);
+
+    QString gatewayUsername() const;
+    void setGatewayUsername(const QString &gatewayUsername);
+
+    QString gatewayPassword() const;
+    void setGatewayPassword(const QString &gatewayPassword);
+
+    QString gatewayServer() const;
+    void setGatewayServer(const QString &gatewayServer);
+
+    QString gatewayDomain() const;
+    void setGatewayDomain(const QString &gatewayDomain);
+
 protected:
-    QWidget* createProtocolSpecificConfigPage() override;
+    QWidget *createProtocolSpecificConfigPage() override;
     void acceptConfig() override;
 
 private:
